 /*****************************************************************************
 *   Copyright (C) 2004 by Michael Schulze                                    *
 *   mike.s@genion.de                                                         *
 *                                                                            *
 *  The code contained in this file is free software; you can redistribute    *
 *  it and/or modify it under the terms of the GNU Lesser General Public      *
 *  License as published by the Free Software Foundation; either version      *
 *  2.1 of the License, or (at your option) any later version.                *
 *                                                                            *
 *  This file is distributed in the hope that it will be useful,              *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
 *  Lesser General Public License for more details.                           *
 *                                                                            *
 *  You should have received a copy of the GNU Lesser General Public          *
 *  License along with this code; if not, write to the Free Software          *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
 *                                                                            *
 *  iTunes and iPod are trademarks of Apple                                   *
 *                                                                            *
 *  This product is not supported/written/published by Apple!                 *
 *****************************************************************************/

#include "listtests.h"
#include "inittest.h"
#include "addtracktest.h"
#include "listtrackstest.h"
#include "checks.h"

#include <qtextcodec.h>

/**
 * my code playground/test case for app logic
 */

typedef std::map<QString, Test *> TestMap; 

inline void insertTest( TestMap& map, Test * test ) {
    map[ test->getName() ] = test;
}

struct CombinedTest : public Test {
    TestMap& m_tests;

    CombinedTest( TestMap& tests )
        : m_tests( tests ) {}

    virtual QString getName() {
        return "all";
    }

    virtual int run( QStringList& arguments ) {
        TestMap::iterator testIter = m_tests.begin();
        for ( ; testIter != m_tests.end(); ++testIter ) {
            Test * test = testIter->second;
            if ( test && test != this ) {
                fprintf( stdout, "\nTEST: %s\n", test->getName().ascii() );
                test->run( arguments );
            }
        }
        return 0;
    }

};

int main( int argc, char ** argv) {

    // register tests
    TestMap tests;
    insertTest( tests, new ListTests() );
    insertTest( tests, new InitTest() );
    insertTest( tests, new AddTrackTest() );
    insertTest( tests, new ListTracksTest() );
    insertTest( tests, new Checks() );
    insertTest( tests, new CombinedTest( tests ) );

    if ( argc < 2 ) {
        TestMap::iterator iter = tests.begin();
        fprintf( stderr, "Usage: ipodtest <" );
        for ( ; iter != tests.end(); ++iter ) {
            fprintf( stderr, "%s", (*iter).first.ascii() );
            fprintf( stderr, "|" );
        }
        fprintf( stderr, ">\n" );
        return -1;
    }

    QStringList arguments;

    for ( int i = 2; i < argc; i++ ) {
        arguments << argv[ i ];
    }

    printf( "current locale is %s\n", QTextCodec::locale() );

    TestMap::iterator iter = tests.find( argv[ 1 ] );
    if ( iter != tests.end() ) {
        (*iter).second->run( arguments );
    } else {
        fprintf( stderr, "TEST %s could not be found\n", argv[ 1 ] );
    }

}

