/***************************************************************************
 *   Copyright (C) 2006 by Michael Schulze   *
 *   mike.s@genion.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "test.h"
#include "itunesdb.h"

/**
 * @brief All kinds of tests listing tracks and playlists
 */
class ListTests : public Test {


    /**
     * Creates a smart playlist with a rule for the matching the songs played in
     * the last 2 weeks and a limit for the 30 last played songs.
     */
    void createRecentlyPlayedList( ITunesDB& itunesdb );

    /**
     * Creates a smart playlist with a rule for the matching the songs skipped in
     * the last 2 weeks and a limit for the 30 last played songs.
     */
    void createRecentlySkippedList( ITunesDB& itunesdb );

    /**
     * Creates a smart playlist for the 25 most often played tracks
     */
    void createTop25List( ITunesDB& itunesdb );

    /**
     * Creates a new smart playlist with all the tracks that haven't been played
     * or skipped yet
     */
    void createNeverPlayedBeforeList( ITunesDB& itunsdb );

    /**
     * Creates a new smart playlist with all the top rated tracks in random
     * sort order.
     */
    void createHighestRated( ITunesDB& itunesdb );

    /**
     * Creates a playlist with the tracks added in the last 2 weeks
     */
    void createNewestAdditionsList( ITunesDB& itunesdb );

    /**
     * Prints the contents of a playlist in the desired order to stdout.
     */
    void printSortedBy( ITunesDBPlaylist& playlist, itunesdb::Playlist::Sortorder order );

    /**
     * prints out all the tracks grouped by artist and album
     */
    void printTracksByArtist( const ITunesDB& itunesdb );

    /**
     * Print out all the playlists.
     */
    void printPlaylists( const ITunesDB& itunesdb );

public:

    virtual QString getName();

    virtual int run( QStringList& );

};

